summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorSébastien Villemot <sebastien@debian.org>2016-06-27 20:07:25 -0600
committerJulien Langou <julien.langou@ucdenver.edu>2016-06-27 20:07:25 -0600
commit40a3b2fb153ab14ba4d5b51d6dbe1ec12f1578e9 (patch)
treea99023ddd220c0c7c723164ef3b74026a8dc1bd6
parent5efe3599486cc73ceead93f61ce1999eed96be11 (diff)
downloadlapack-40a3b2fb153ab14ba4d5b51d6dbe1ec12f1578e9.tar.gz
lapack-40a3b2fb153ab14ba4d5b51d6dbe1ec12f1578e9.tar.bz2
lapack-40a3b2fb153ab14ba4d5b51d6dbe1ec12f1578e9.zip
Description: Fix various typos
Author: Sébastien Villemot <sebastien@debian.org> Forwarded: yes, by email to lapack@cs.utk.edu on 2016-06-26
-rw-r--r--BLAS/SRC/ctbmv.f2
-rw-r--r--BLAS/SRC/ctpmv.f2
-rw-r--r--BLAS/SRC/ctrmv.f2
-rw-r--r--BLAS/SRC/dtbmv.f2
-rw-r--r--BLAS/SRC/dtpmv.f2
-rw-r--r--BLAS/SRC/dtrmv.f2
-rw-r--r--BLAS/SRC/stbmv.f2
-rw-r--r--BLAS/SRC/stpmv.f2
-rw-r--r--BLAS/SRC/strmv.f2
-rw-r--r--BLAS/SRC/ztbmv.f2
-rw-r--r--BLAS/SRC/ztpmv.f2
-rw-r--r--BLAS/SRC/ztrmv.f2
-rw-r--r--SRC/cgejsv.f4
-rw-r--r--SRC/cgelsd.f4
-rw-r--r--SRC/ctprfb.f2
-rw-r--r--SRC/dgejsv.f4
-rw-r--r--SRC/dgelsd.f2
-rw-r--r--SRC/dlag2s.f2
-rw-r--r--SRC/dlat2s.f2
-rw-r--r--SRC/dtprfb.f2
-rw-r--r--SRC/sgejsv.f4
-rw-r--r--SRC/sgelsd.f2
-rw-r--r--SRC/stprfb.f2
-rw-r--r--SRC/zgejsv.f4
-rw-r--r--SRC/zgelsd.f4
-rw-r--r--SRC/zlag2c.f2
-rw-r--r--SRC/zlat2c.f2
-rw-r--r--SRC/ztprfb.f2
-rw-r--r--TESTING/EIG/cchkbk.f2
-rw-r--r--TESTING/EIG/dchkbk.f2
-rw-r--r--TESTING/EIG/schkbk.f2
-rw-r--r--TESTING/EIG/zchkbk.f2
-rw-r--r--TESTING/LIN/cchkrfp.f2
-rw-r--r--TESTING/LIN/cdrvrf2.f10
-rw-r--r--TESTING/LIN/cdrvrfp.f2
-rw-r--r--TESTING/LIN/dchkrfp.f2
-rw-r--r--TESTING/LIN/ddrvrf2.f10
-rw-r--r--TESTING/LIN/ddrvrfp.f2
-rw-r--r--TESTING/LIN/schkrfp.f2
-rw-r--r--TESTING/LIN/sdrvrf2.f10
-rw-r--r--TESTING/LIN/sdrvrfp.f2
-rw-r--r--TESTING/LIN/zchkrfp.f2
-rw-r--r--TESTING/LIN/zdrvrf2.f10
-rw-r--r--TESTING/LIN/zdrvrfp.f2
-rw-r--r--TESTING/MATGEN/claror.f2
-rw-r--r--TESTING/MATGEN/clatm5.f2
-rw-r--r--TESTING/MATGEN/clatm6.f2
-rw-r--r--TESTING/MATGEN/dlatm5.f2
-rw-r--r--TESTING/MATGEN/dlatm6.f2
-rw-r--r--TESTING/MATGEN/slatm5.f2
-rw-r--r--TESTING/MATGEN/slatm6.f2
-rw-r--r--TESTING/MATGEN/zlatm5.f2
-rw-r--r--TESTING/MATGEN/zlatm6.f2
53 files changed, 75 insertions, 75 deletions
diff --git a/BLAS/SRC/ctbmv.f b/BLAS/SRC/ctbmv.f
index 45d17b86..47f59d80 100644
--- a/BLAS/SRC/ctbmv.f
+++ b/BLAS/SRC/ctbmv.f
@@ -146,7 +146,7 @@
*> ( 1 + ( n - 1 )*abs( INCX ) ).
*> Before entry, the incremented array X must contain the n
*> element vector x. On exit, X is overwritten with the
-*> tranformed vector x.
+*> transformed vector x.
*> \endverbatim
*>
*> \param[in] INCX
diff --git a/BLAS/SRC/ctpmv.f b/BLAS/SRC/ctpmv.f
index 14c7417d..3df93d8f 100644
--- a/BLAS/SRC/ctpmv.f
+++ b/BLAS/SRC/ctpmv.f
@@ -102,7 +102,7 @@
*> ( 1 + ( n - 1 )*abs( INCX ) ).
*> Before entry, the incremented array X must contain the n
*> element vector x. On exit, X is overwritten with the
-*> tranformed vector x.
+*> transformed vector x.
*> \endverbatim
*>
*> \param[in] INCX
diff --git a/BLAS/SRC/ctrmv.f b/BLAS/SRC/ctrmv.f
index f2bfbc2e..fb4cd128 100644
--- a/BLAS/SRC/ctrmv.f
+++ b/BLAS/SRC/ctrmv.f
@@ -107,7 +107,7 @@
*> ( 1 + ( n - 1 )*abs( INCX ) ).
*> Before entry, the incremented array X must contain the n
*> element vector x. On exit, X is overwritten with the
-*> tranformed vector x.
+*> transformed vector x.
*> \endverbatim
*>
*> \param[in] INCX
diff --git a/BLAS/SRC/dtbmv.f b/BLAS/SRC/dtbmv.f
index 86e027f8..851f4457 100644
--- a/BLAS/SRC/dtbmv.f
+++ b/BLAS/SRC/dtbmv.f
@@ -146,7 +146,7 @@
*> ( 1 + ( n - 1 )*abs( INCX ) ).
*> Before entry, the incremented array X must contain the n
*> element vector x. On exit, X is overwritten with the
-*> tranformed vector x.
+*> transformed vector x.
*> \endverbatim
*>
*> \param[in] INCX
diff --git a/BLAS/SRC/dtpmv.f b/BLAS/SRC/dtpmv.f
index 5af8f1d9..905d748c 100644
--- a/BLAS/SRC/dtpmv.f
+++ b/BLAS/SRC/dtpmv.f
@@ -102,7 +102,7 @@
*> ( 1 + ( n - 1 )*abs( INCX ) ).
*> Before entry, the incremented array X must contain the n
*> element vector x. On exit, X is overwritten with the
-*> tranformed vector x.
+*> transformed vector x.
*> \endverbatim
*>
*> \param[in] INCX
diff --git a/BLAS/SRC/dtrmv.f b/BLAS/SRC/dtrmv.f
index 71459fe7..5eb2f404 100644
--- a/BLAS/SRC/dtrmv.f
+++ b/BLAS/SRC/dtrmv.f
@@ -107,7 +107,7 @@
*> ( 1 + ( n - 1 )*abs( INCX ) ).
*> Before entry, the incremented array X must contain the n
*> element vector x. On exit, X is overwritten with the
-*> tranformed vector x.
+*> transformed vector x.
*> \endverbatim
*>
*> \param[in] INCX
diff --git a/BLAS/SRC/stbmv.f b/BLAS/SRC/stbmv.f
index bd5036c0..12c15429 100644
--- a/BLAS/SRC/stbmv.f
+++ b/BLAS/SRC/stbmv.f
@@ -146,7 +146,7 @@
*> ( 1 + ( n - 1 )*abs( INCX ) ).
*> Before entry, the incremented array X must contain the n
*> element vector x. On exit, X is overwritten with the
-*> tranformed vector x.
+*> transformed vector x.
*> \endverbatim
*>
*> \param[in] INCX
diff --git a/BLAS/SRC/stpmv.f b/BLAS/SRC/stpmv.f
index e66dc4ce..d712a99e 100644
--- a/BLAS/SRC/stpmv.f
+++ b/BLAS/SRC/stpmv.f
@@ -102,7 +102,7 @@
*> ( 1 + ( n - 1 )*abs( INCX ) ).
*> Before entry, the incremented array X must contain the n
*> element vector x. On exit, X is overwritten with the
-*> tranformed vector x.
+*> transformed vector x.
*> \endverbatim
*>
*> \param[in] INCX
diff --git a/BLAS/SRC/strmv.f b/BLAS/SRC/strmv.f
index 8f3a36f1..2fe99018 100644
--- a/BLAS/SRC/strmv.f
+++ b/BLAS/SRC/strmv.f
@@ -107,7 +107,7 @@
*> ( 1 + ( n - 1 )*abs( INCX ) ).
*> Before entry, the incremented array X must contain the n
*> element vector x. On exit, X is overwritten with the
-*> tranformed vector x.
+*> transformed vector x.
*> \endverbatim
*>
*> \param[in] INCX
diff --git a/BLAS/SRC/ztbmv.f b/BLAS/SRC/ztbmv.f
index 2b5780b1..6c52da45 100644
--- a/BLAS/SRC/ztbmv.f
+++ b/BLAS/SRC/ztbmv.f
@@ -146,7 +146,7 @@
*> ( 1 + ( n - 1 )*abs( INCX ) ).
*> Before entry, the incremented array X must contain the n
*> element vector x. On exit, X is overwritten with the
-*> tranformed vector x.
+*> transformed vector x.
*> \endverbatim
*>
*> \param[in] INCX
diff --git a/BLAS/SRC/ztpmv.f b/BLAS/SRC/ztpmv.f
index e277ec1a..547dc012 100644
--- a/BLAS/SRC/ztpmv.f
+++ b/BLAS/SRC/ztpmv.f
@@ -102,7 +102,7 @@
*> ( 1 + ( n - 1 )*abs( INCX ) ).
*> Before entry, the incremented array X must contain the n
*> element vector x. On exit, X is overwritten with the
-*> tranformed vector x.
+*> transformed vector x.
*> \endverbatim
*>
*> \param[in] INCX
diff --git a/BLAS/SRC/ztrmv.f b/BLAS/SRC/ztrmv.f
index 8d7974a0..fd9263ce 100644
--- a/BLAS/SRC/ztrmv.f
+++ b/BLAS/SRC/ztrmv.f
@@ -107,7 +107,7 @@
*> ( 1 + ( n - 1 )*abs( INCX ) ).
*> Before entry, the incremented array X must contain the n
*> element vector x. On exit, X is overwritten with the
-*> tranformed vector x.
+*> transformed vector x.
*> \endverbatim
*>
*> \param[in] INCX
diff --git a/SRC/cgejsv.f b/SRC/cgejsv.f
index bee18fdf..459e1f42 100644
--- a/SRC/cgejsv.f
+++ b/SRC/cgejsv.f
@@ -420,7 +420,7 @@
*> \verbatim
*> INFO is INTEGER
*> < 0 : if INFO = -i, then the i-th argument had an illegal value.
-*> = 0 : successfull exit;
+*> = 0 : successful exit;
*> > 0 : CGEJSV did not converge in the maximal allowed number
*> of sweeps. The computed values may be inaccurate.
*> \endverbatim
@@ -471,7 +471,7 @@
*> implemented as in [3]. We have a new version of CGEQP3 under development
*> that is more robust than the current one in LAPACK, with a cleaner cut in
*> rank defficient cases. It will be available in the SIGMA library [4].
-*> If M is much larger than N, it is obvious that the inital QRF with
+*> If M is much larger than N, it is obvious that the initial QRF with
*> column pivoting can be preprocessed by the QRF without pivoting. That
*> well known trick is not used in CGEJSV because in some cases heavy row
*> weighting can be treated with complete pivoting. The overhead in cases
diff --git a/SRC/cgelsd.f b/SRC/cgelsd.f
index 38da3093..3dc322b9 100644
--- a/SRC/cgelsd.f
+++ b/SRC/cgelsd.f
@@ -50,10 +50,10 @@
*>
*> The problem is solved in three steps:
*> (1) Reduce the coefficient matrix A to bidiagonal form with
-*> Householder tranformations, reducing the original problem
+*> Householder transformations, reducing the original problem
*> into a "bidiagonal least squares problem" (BLS)
*> (2) Solve the BLS using a divide and conquer approach.
-*> (3) Apply back all the Householder tranformations to solve
+*> (3) Apply back all the Householder transformations to solve
*> the original least squares problem.
*>
*> The effective rank of A is determined by treating as zero those
diff --git a/SRC/ctprfb.f b/SRC/ctprfb.f
index 77b376f3..fea50f94 100644
--- a/SRC/ctprfb.f
+++ b/SRC/ctprfb.f
@@ -145,7 +145,7 @@
*> (LDA,N) if SIDE = 'L' or (LDA,K) if SIDE = 'R'
*> On entry, the K-by-N or M-by-K matrix A.
*> On exit, A is overwritten by the corresponding block of
-*> H*C or H**H*C or C*H or C*H**H. See Futher Details.
+*> H*C or H**H*C or C*H or C*H**H. See Further Details.
*> \endverbatim
*>
*> \param[in] LDA
diff --git a/SRC/dgejsv.f b/SRC/dgejsv.f
index fc91ab51..4f3143c7 100644
--- a/SRC/dgejsv.f
+++ b/SRC/dgejsv.f
@@ -378,7 +378,7 @@
*> \verbatim
*> INFO is INTEGER
*> < 0 : if INFO = -i, then the i-th argument had an illegal value.
-*> = 0 : successfull exit;
+*> = 0 : successful exit;
*> > 0 : DGEJSV did not converge in the maximal allowed number
*> of sweeps. The computed values may be inaccurate.
*> \endverbatim
@@ -429,7 +429,7 @@
*> implemented as in [3]. We have a new version of DGEQP3 under development
*> that is more robust than the current one in LAPACK, with a cleaner cut in
*> rank defficient cases. It will be available in the SIGMA library [4].
-*> If M is much larger than N, it is obvious that the inital QRF with
+*> If M is much larger than N, it is obvious that the initial QRF with
*> column pivoting can be preprocessed by the QRF without pivoting. That
*> well known trick is not used in DGEJSV because in some cases heavy row
*> weighting can be treated with complete pivoting. The overhead in cases
diff --git a/SRC/dgelsd.f b/SRC/dgelsd.f
index 7629071f..53e77417 100644
--- a/SRC/dgelsd.f
+++ b/SRC/dgelsd.f
@@ -52,7 +52,7 @@
*> Householder transformations, reducing the original problem
*> into a "bidiagonal least squares problem" (BLS)
*> (2) Solve the BLS using a divide and conquer approach.
-*> (3) Apply back all the Householder tranformations to solve
+*> (3) Apply back all the Householder transformations to solve
*> the original least squares problem.
*>
*> The effective rank of A is determined by treating as zero those
diff --git a/SRC/dlag2s.f b/SRC/dlag2s.f
index 3cf27db2..2bace1f7 100644
--- a/SRC/dlag2s.f
+++ b/SRC/dlag2s.f
@@ -39,7 +39,7 @@
*>
*> RMAX is the overflow for the SINGLE PRECISION arithmetic
*> DLAG2S checks that all the entries of A are between -RMAX and
-*> RMAX. If not the convertion is aborted and a flag is raised.
+*> RMAX. If not the conversion is aborted and a flag is raised.
*>
*> This is an auxiliary routine so there is no argument checking.
*> \endverbatim
diff --git a/SRC/dlat2s.f b/SRC/dlat2s.f
index 63f106ad..57613c0d 100644
--- a/SRC/dlat2s.f
+++ b/SRC/dlat2s.f
@@ -40,7 +40,7 @@
*>
*> RMAX is the overflow for the SINGLE PRECISION arithmetic
*> DLAS2S checks that all the entries of A are between -RMAX and
-*> RMAX. If not the convertion is aborted and a flag is raised.
+*> RMAX. If not the conversion is aborted and a flag is raised.
*>
*> This is an auxiliary routine so there is no argument checking.
*> \endverbatim
diff --git a/SRC/dtprfb.f b/SRC/dtprfb.f
index 08976d06..409cbf2f 100644
--- a/SRC/dtprfb.f
+++ b/SRC/dtprfb.f
@@ -145,7 +145,7 @@
*> (LDA,N) if SIDE = 'L' or (LDA,K) if SIDE = 'R'
*> On entry, the K-by-N or M-by-K matrix A.
*> On exit, A is overwritten by the corresponding block of
-*> H*C or H**T*C or C*H or C*H**T. See Futher Details.
+*> H*C or H**T*C or C*H or C*H**T. See Further Details.
*> \endverbatim
*>
*> \param[in] LDA
diff --git a/SRC/sgejsv.f b/SRC/sgejsv.f
index 7d80d4ec..a89d5dae 100644
--- a/SRC/sgejsv.f
+++ b/SRC/sgejsv.f
@@ -378,7 +378,7 @@
*> \verbatim
*> INFO is INTEGER
*> < 0 : if INFO = -i, then the i-th argument had an illegal value.
-*> = 0 : successfull exit;
+*> = 0 : successful exit;
*> > 0 : SGEJSV did not converge in the maximal allowed number
*> of sweeps. The computed values may be inaccurate.
*> \endverbatim
@@ -429,7 +429,7 @@
*> implemented as in [3]. We have a new version of SGEQP3 under development
*> that is more robust than the current one in LAPACK, with a cleaner cut in
*> rank defficient cases. It will be available in the SIGMA library [4].
-*> If M is much larger than N, it is obvious that the inital QRF with
+*> If M is much larger than N, it is obvious that the initial QRF with
*> column pivoting can be preprocessed by the QRF without pivoting. That
*> well known trick is not used in SGEJSV because in some cases heavy row
*> weighting can be treated with complete pivoting. The overhead in cases
diff --git a/SRC/sgelsd.f b/SRC/sgelsd.f
index d03f37b3..844b6cda 100644
--- a/SRC/sgelsd.f
+++ b/SRC/sgelsd.f
@@ -52,7 +52,7 @@
*> Householder transformations, reducing the original problem
*> into a "bidiagonal least squares problem" (BLS)
*> (2) Solve the BLS using a divide and conquer approach.
-*> (3) Apply back all the Householder tranformations to solve
+*> (3) Apply back all the Householder transformations to solve
*> the original least squares problem.
*>
*> The effective rank of A is determined by treating as zero those
diff --git a/SRC/stprfb.f b/SRC/stprfb.f
index 01383aeb..4ae3f0b0 100644
--- a/SRC/stprfb.f
+++ b/SRC/stprfb.f
@@ -145,7 +145,7 @@
*> (LDA,N) if SIDE = 'L' or (LDA,K) if SIDE = 'R'
*> On entry, the K-by-N or M-by-K matrix A.
*> On exit, A is overwritten by the corresponding block of
-*> H*C or H^H*C or C*H or C*H^H. See Futher Details.
+*> H*C or H^H*C or C*H or C*H^H. See Further Details.
*> \endverbatim
*>
*> \param[in] LDA
diff --git a/SRC/zgejsv.f b/SRC/zgejsv.f
index ad47a407..15bbab07 100644
--- a/SRC/zgejsv.f
+++ b/SRC/zgejsv.f
@@ -420,7 +420,7 @@
*> \verbatim
*> INFO is INTEGER
*> < 0 : if INFO = -i, then the i-th argument had an illegal value.
-*> = 0 : successfull exit;
+*> = 0 : successful exit;
*> > 0 : ZGEJSV did not converge in the maximal allowed number
*> of sweeps. The computed values may be inaccurate.
*> \endverbatim
@@ -471,7 +471,7 @@
*> implemented as in [3]. We have a new version of ZGEQP3 under development
*> that is more robust than the current one in LAPACK, with a cleaner cut in
*> rank defficient cases. It will be available in the SIGMA library [4].
-*> If M is much larger than N, it is obvious that the inital QRF with
+*> If M is much larger than N, it is obvious that the initial QRF with
*> column pivoting can be preprocessed by the QRF without pivoting. That
*> well known trick is not used in ZGEJSV because in some cases heavy row
*> weighting can be treated with complete pivoting. The overhead in cases
diff --git a/SRC/zgelsd.f b/SRC/zgelsd.f
index aeaa96ed..81731760 100644
--- a/SRC/zgelsd.f
+++ b/SRC/zgelsd.f
@@ -50,10 +50,10 @@
*>
*> The problem is solved in three steps:
*> (1) Reduce the coefficient matrix A to bidiagonal form with
-*> Householder tranformations, reducing the original problem
+*> Householder transformations, reducing the original problem
*> into a "bidiagonal least squares problem" (BLS)
*> (2) Solve the BLS using a divide and conquer approach.
-*> (3) Apply back all the Householder tranformations to solve
+*> (3) Apply back all the Householder transformations to solve
*> the original least squares problem.
*>
*> The effective rank of A is determined by treating as zero those
diff --git a/SRC/zlag2c.f b/SRC/zlag2c.f
index a8c1ce1f..7ff69d02 100644
--- a/SRC/zlag2c.f
+++ b/SRC/zlag2c.f
@@ -38,7 +38,7 @@
*>
*> RMAX is the overflow for the SINGLE PRECISION arithmetic
*> ZLAG2C checks that all the entries of A are between -RMAX and
-*> RMAX. If not the convertion is aborted and a flag is raised.
+*> RMAX. If not the conversion is aborted and a flag is raised.
*>
*> This is an auxiliary routine so there is no argument checking.
*> \endverbatim
diff --git a/SRC/zlat2c.f b/SRC/zlat2c.f
index 8b9af860..7d60c125 100644
--- a/SRC/zlat2c.f
+++ b/SRC/zlat2c.f
@@ -40,7 +40,7 @@
*>
*> RMAX is the overflow for the SINGLE PRECISION arithmetic
*> ZLAT2C checks that all the entries of A are between -RMAX and
-*> RMAX. If not the convertion is aborted and a flag is raised.
+*> RMAX. If not the conversion is aborted and a flag is raised.
*>
*> This is an auxiliary routine so there is no argument checking.
*> \endverbatim
diff --git a/SRC/ztprfb.f b/SRC/ztprfb.f
index 6e452bb6..c46c2ef2 100644
--- a/SRC/ztprfb.f
+++ b/SRC/ztprfb.f
@@ -145,7 +145,7 @@
*> (LDA,N) if SIDE = 'L' or (LDA,K) if SIDE = 'R'
*> On entry, the K-by-N or M-by-K matrix A.
*> On exit, A is overwritten by the corresponding block of
-*> H*C or H**H*C or C*H or C*H**H. See Futher Details.
+*> H*C or H**H*C or C*H or C*H**H. See Further Details.
*> \endverbatim
*>
*> \param[in] LDA
diff --git a/TESTING/EIG/cchkbk.f b/TESTING/EIG/cchkbk.f
index e04ef1e7..d1ad8967 100644
--- a/TESTING/EIG/cchkbk.f
+++ b/TESTING/EIG/cchkbk.f
@@ -21,7 +21,7 @@
*> \verbatim
*>
*> CCHKBK tests CGEBAK, a routine for backward transformation of
-*> the computed right or left eigenvectors if the orginal matrix
+*> the computed right or left eigenvectors if the original matrix
*> was preprocessed by balance subroutine CGEBAL.
*> \endverbatim
*
diff --git a/TESTING/EIG/dchkbk.f b/TESTING/EIG/dchkbk.f
index 42ee948b..1d61fde6 100644
--- a/TESTING/EIG/dchkbk.f
+++ b/TESTING/EIG/dchkbk.f
@@ -21,7 +21,7 @@
*> \verbatim
*>
*> DCHKBK tests DGEBAK, a routine for backward transformation of
-*> the computed right or left eigenvectors if the orginal matrix
+*> the computed right or left eigenvectors if the original matrix
*> was preprocessed by balance subroutine DGEBAL.
*> \endverbatim
*
diff --git a/TESTING/EIG/schkbk.f b/TESTING/EIG/schkbk.f
index 7cc799b8..19521012 100644
--- a/TESTING/EIG/schkbk.f
+++ b/TESTING/EIG/schkbk.f
@@ -21,7 +21,7 @@
*> \verbatim
*>
*> SCHKBK tests SGEBAK, a routine for backward transformation of
-*> the computed right or left eigenvectors if the orginal matrix
+*> the computed right or left eigenvectors if the original matrix
*> was preprocessed by balance subroutine SGEBAL.
*> \endverbatim
*
diff --git a/TESTING/EIG/zchkbk.f b/TESTING/EIG/zchkbk.f
index cfd14de3..9ee77464 100644
--- a/TESTING/EIG/zchkbk.f
+++ b/TESTING/EIG/zchkbk.f
@@ -21,7 +21,7 @@
*> \verbatim
*>
*> ZCHKBK tests ZGEBAK, a routine for backward transformation of
-*> the computed right or left eigenvectors if the orginal matrix
+*> the computed right or left eigenvectors if the original matrix
*> was preprocessed by balance subroutine ZGEBAL.
*> \endverbatim
*
diff --git a/TESTING/LIN/cchkrfp.f b/TESTING/LIN/cchkrfp.f
index a3fa4b1d..df871426 100644
--- a/TESTING/LIN/cchkrfp.f
+++ b/TESTING/LIN/cchkrfp.f
@@ -253,7 +253,7 @@
CALL CDRVRF1( NOUT, NN, NVAL, THRESH, WORKA, NMAX, WORKARF,
+ S_WORK_CLANHE )
*
-* Test the convertion routines:
+* Test the conversion routines:
* chfttp, ctpthf, ctfttr, ctrttf, ctrttp and ctpttr.
*
CALL CDRVRF2( NOUT, NN, NVAL, WORKA, NMAX, WORKARF,
diff --git a/TESTING/LIN/cdrvrfp.f b/TESTING/LIN/cdrvrfp.f
index 07524267..6357177a 100644
--- a/TESTING/LIN/cdrvrfp.f
+++ b/TESTING/LIN/cdrvrfp.f
@@ -53,7 +53,7 @@
*> This testing routine follow the same tests as CDRVPO (test for the full
*> format Symmetric Positive Definite solver).
*>
-*> The tests are performed in Full Format, convertion back and forth from
+*> The tests are performed in Full Format, conversion back and forth from
*> full format to RFP format are performed using the routines CTRTTF and
*> CTFTTR.
*>
diff --git a/TESTING/LIN/dchkrfp.f b/TESTING/LIN/dchkrfp.f
index 718a246f..757df28c 100644
--- a/TESTING/LIN/dchkrfp.f
+++ b/TESTING/LIN/dchkrfp.f
@@ -252,7 +252,7 @@
CALL DDRVRF1( NOUT, NN, NVAL, THRESH, WORKA, NMAX, WORKARF,
+ D_WORK_DLANSY )
*
-* Test the convertion routines:
+* Test the conversion routines:
* dtfttp, dtpttf, dtfttr, dtrttf, dtrttp and dtpttr.
*
CALL DDRVRF2( NOUT, NN, NVAL, WORKA, NMAX, WORKARF,
diff --git a/TESTING/LIN/ddrvrfp.f b/TESTING/LIN/ddrvrfp.f
index 5f44006b..9bb5d7c0 100644
--- a/TESTING/LIN/ddrvrfp.f
+++ b/TESTING/LIN/ddrvrfp.f
@@ -52,7 +52,7 @@
*> This testing routine follow the same tests as DDRVPO (test for the full
*> format Symmetric Positive Definite solver).
*>
-*> The tests are performed in Full Format, convertion back and forth from
+*> The tests are performed in Full Format, conversion back and forth from
*> full format to RFP format are performed using the routines DTRTTF and
*> DTFTTR.
*>
diff --git a/TESTING/LIN/schkrfp.f b/TESTING/LIN/schkrfp.f
index 053949c1..f092f685 100644
--- a/TESTING/LIN/schkrfp.f
+++ b/TESTING/LIN/schkrfp.f
@@ -251,7 +251,7 @@
CALL SDRVRF1( NOUT, NN, NVAL, THRESH, WORKA, NMAX, WORKARF,
+ S_WORK_SLANSY )
*
-* Test the convertion routines:
+* Test the conversion routines:
* stfttp, stpttf, stfttr, strttf, strttp and stpttr.
*
CALL SDRVRF2( NOUT, NN, NVAL, WORKA, NMAX, WORKARF,
diff --git a/TESTING/LIN/sdrvrfp.f b/TESTING/LIN/sdrvrfp.f
index c79b5a2c..04737e77 100644
--- a/TESTING/LIN/sdrvrfp.f
+++ b/TESTING/LIN/sdrvrfp.f
@@ -52,7 +52,7 @@
*> This testing routine follow the same tests as DDRVPO (test for the full
*> format Symmetric Positive Definite solver).
*>
-*> The tests are performed in Full Format, convertion back and forth from
+*> The tests are performed in Full Format, conversion back and forth from
*> full format to RFP format are performed using the routines STRTTF and
*> STFTTR.
*>
diff --git a/TESTING/LIN/zchkrfp.f b/TESTING/LIN/zchkrfp.f
index 0597b9d0..f010ca4a 100644
--- a/TESTING/LIN/zchkrfp.f
+++ b/TESTING/LIN/zchkrfp.f
@@ -253,7 +253,7 @@
CALL ZDRVRF1( NOUT, NN, NVAL, THRESH, WORKA, NMAX, WORKARF,
+ D_WORK_ZLANHE )
*
-* Test the convertion routines:
+* Test the conversion routines:
* zhfttp, ztpthf, ztfttr, ztrttf, ztrttp and ztpttr.
*
CALL ZDRVRF2( NOUT, NN, NVAL, WORKA, NMAX, WORKARF,
diff --git a/TESTING/LIN/zdrvrfp.f b/TESTING/LIN/zdrvrfp.f
index e101abaf..220f0cdd 100644
--- a/TESTING/LIN/zdrvrfp.f
+++ b/TESTING/LIN/zdrvrfp.f
@@ -53,7 +53,7 @@
*> This testing routine follow the same tests as ZDRVPO (test for the full
*> format Symmetric Positive Definite solver).
*>
-*> The tests are performed in Full Format, convertion back and forth from
+*> The tests are performed in Full Format, conversion back and forth from
*> full format to RFP format are performed using the routines ZTRTTF and
*> ZTFTTR.
*>
diff --git a/TESTING/MATGEN/claror.f b/TESTING/MATGEN/claror.f
index 76842907..9cabe136 100644
--- a/TESTING/MATGEN/claror.f
+++ b/TESTING/MATGEN/claror.f
@@ -70,7 +70,7 @@
*> columns will be orthogonal, the remaining columns being
*> zero.
*> For matrices where M > N, just use the previous
-*> explaination, interchanging 'L' and 'R' and "rows" and
+*> explanation, interchanging 'L' and 'R' and "rows" and
*> "columns".
*>
*> Not modified.
diff --git a/TESTING/MATGEN/clatm5.f b/TESTING/MATGEN/clatm5.f
index bce75f1e..8a3c96be 100644
--- a/TESTING/MATGEN/clatm5.f
+++ b/TESTING/MATGEN/clatm5.f
@@ -49,7 +49,7 @@
*> \verbatim
*> PRTYPE is INTEGER
*> "Points" to a certain type of the matrices to generate
-*> (see futher details).
+*> (see further details).
*> \endverbatim
*>
*> \param[in] M
diff --git a/TESTING/MATGEN/clatm6.f b/TESTING/MATGEN/clatm6.f
index 1f80914d..d34d53c1 100644
--- a/TESTING/MATGEN/clatm6.f
+++ b/TESTING/MATGEN/clatm6.f
@@ -71,7 +71,7 @@
*> \param[in] TYPE
*> \verbatim
*> TYPE is INTEGER
-*> Specifies the problem type (see futher details).
+*> Specifies the problem type (see further details).
*> \endverbatim
*>
*> \param[in] N
diff --git a/TESTING/MATGEN/dlatm5.f b/TESTING/MATGEN/dlatm5.f
index f7581ad8..40d8360d 100644
--- a/TESTING/MATGEN/dlatm5.f
+++ b/TESTING/MATGEN/dlatm5.f
@@ -49,7 +49,7 @@
*> \verbatim
*> PRTYPE is INTEGER
*> "Points" to a certain type of the matrices to generate
-*> (see futher details).
+*> (see further details).
*> \endverbatim
*>
*> \param[in] M
diff --git a/TESTING/MATGEN/dlatm6.f b/TESTING/MATGEN/dlatm6.f
index ca64f862..2a6823d7 100644
--- a/TESTING/MATGEN/dlatm6.f
+++ b/TESTING/MATGEN/dlatm6.f
@@ -73,7 +73,7 @@
*> \param[in] TYPE
*> \verbatim
*> TYPE is INTEGER
-*> Specifies the problem type (see futher details).
+*> Specifies the problem type (see further details).
*> \endverbatim
*>
*> \param[in] N
diff --git a/TESTING/MATGEN/slatm5.f b/TESTING/MATGEN/slatm5.f
index eeb3e6f3..7a1f2601 100644
--- a/TESTING/MATGEN/slatm5.f
+++ b/TESTING/MATGEN/slatm5.f
@@ -49,7 +49,7 @@
*> \verbatim
*> PRTYPE is INTEGER
*> "Points" to a certain type of the matrices to generate
-*> (see futher details).
+*> (see further details).
*> \endverbatim
*>
*> \param[in] M
diff --git a/TESTING/MATGEN/slatm6.f b/TESTING/MATGEN/slatm6.f
index e606becf..0138b012 100644
--- a/TESTING/MATGEN/slatm6.f
+++ b/TESTING/MATGEN/slatm6.f
@@ -73,7 +73,7 @@
*> \param[in] TYPE
*> \verbatim
*> TYPE is INTEGER
-*> Specifies the problem type (see futher details).
+*> Specifies the problem type (see further details).
*> \endverbatim
*>
*> \param[in] N
diff --git a/TESTING/MATGEN/zlatm5.f b/TESTING/MATGEN/zlatm5.f
index 4020c855..b0f1516f 100644
--- a/TESTING/MATGEN/zlatm5.f
+++ b/TESTING/MATGEN/zlatm5.f
@@ -49,7 +49,7 @@
*> \verbatim
*> PRTYPE is INTEGER
*> "Points" to a certain type of the matrices to generate
-*> (see futher details).
+*> (see further details).
*> \endverbatim
*>
*> \param[in] M
diff --git a/TESTING/MATGEN/zlatm6.f b/TESTING/MATGEN/zlatm6.f
index b11a5ea5..8dc258ac 100644
--- a/TESTING/MATGEN/zlatm6.f
+++ b/TESTING/MATGEN/zlatm6.f
@@ -71,7 +71,7 @@
*> \param[in] TYPE
*> \verbatim
*> TYPE is INTEGER
-*> Specifies the problem type (see futher details).
+*> Specifies the problem type (see further details).
*> \endverbatim
*>
*> \param[in] N
diff --git a/TESTING/LIN/cdrvrf2.f b/TESTING/LIN/cdrvrf2.f
index d902701c..bdfb0a53 100644
--- a/TESTING/LIN/cdrvrf2.f
+++ b/TESTING/LIN/cdrvrf2.f
@@ -24,7 +24,7 @@
*>
*> \verbatim
*>
*> CDRVRF2 tests the LAPACK RFP convertion routines.
*> \endverbatim
*
* Arguments:
@@ -248,13 +248,13 @@
WRITE( NOUT, FMT = 9996 ) NERRS, NRUN
END IF
*
- 9999 FORMAT( 1X, ' *** Error(s) while testing the RFP convertion',
+ 9999 FORMAT( 1X, ' *** Error(s) while testing the RFP conversion',
+ ' routines ***')
- 9998 FORMAT( 1X, ' Error in RFP,convertion routines N=',I5,
+ 9998 FORMAT( 1X, ' Error in RFP,conversion routines N=',I5,
+ ' UPLO=''', A1, ''', FORM =''',A1,'''')
- 9997 FORMAT( 1X, 'All tests for the RFP convertion routines passed ( ',
+ 9997 FORMAT( 1X, 'All tests for the RFP conversion routines passed ( ',
+ I5,' tests run)')
- 9996 FORMAT( 1X, 'RFP convertion routines: ',I5,' out of ',I5,
+ 9996 FORMAT( 1X, 'RFP conversion routines: ',I5,' out of ',I5,
+ ' error message recorded')
*
RETURN
@@ -24,7 +24,7 @@
*> \verbatim
*>
-*> CDRVRF2 tests the LAPACK RFP convertion routines.
+*> CDRVRF2 tests the LAPACK RFP conversion routines.
*> \endverbatim
*
diff --git a/TESTING/LIN/ddrvrf2.f b/TESTING/LIN/ddrvrf2.f
index 4509b3ca..03487f50 100644
--- a/TESTING/LIN/ddrvrf2.f
+++ b/TESTING/LIN/ddrvrf2.f
@@ -24,7 +24,7 @@
*>
*> \verbatim
*>
*> DDRVRF2 tests the LAPACK RFP convertion routines.
*> \endverbatim
*
* Arguments:
@@ -248,13 +248,13 @@
WRITE( NOUT, FMT = 9996 ) NERRS, NRUN
END IF
*
- 9999 FORMAT( 1X, ' *** Error(s) while testing the RFP convertion',
+ 9999 FORMAT( 1X, ' *** Error(s) while testing the RFP conversion',
+ ' routines ***')
- 9998 FORMAT( 1X, ' Error in RFP,convertion routines N=',I5,
+ 9998 FORMAT( 1X, ' Error in RFP,conversion routines N=',I5,
+ ' UPLO=''', A1, ''', FORM =''',A1,'''')
- 9997 FORMAT( 1X, 'All tests for the RFP convertion routines passed ( ',
+ 9997 FORMAT( 1X, 'All tests for the RFP conversion routines passed ( ',
+ I5,' tests run)')
- 9996 FORMAT( 1X, 'RFP convertion routines: ',I5,' out of ',I5,
+ 9996 FORMAT( 1X, 'RFP conversion routines: ',I5,' out of ',I5,
+ ' error message recorded')
*
RETURN
@@ -24,7 +24,7 @@
*> \verbatim
*>
-*> DDRVRF2 tests the LAPACK RFP convertion routines.
+*> DDRVRF2 tests the LAPACK RFP conversion routines.
*> \endverbatim
*
diff --git a/TESTING/LIN/sdrvrf2.f b/TESTING/LIN/sdrvrf2.f
index 685681bb..921065ac 100644
--- a/TESTING/LIN/sdrvrf2.f
+++ b/TESTING/LIN/sdrvrf2.f
@@ -24,7 +24,7 @@
*>
*> \verbatim
*>
*> SDRVRF2 tests the LAPACK RFP convertion routines.
*> \endverbatim
*
* Arguments:
@@ -248,13 +248,13 @@
WRITE( NOUT, FMT = 9996 ) NERRS, NRUN
END IF
*
- 9999 FORMAT( 1X, ' *** Error(s) while testing the RFP convertion',
+ 9999 FORMAT( 1X, ' *** Error(s) while testing the RFP conversion',
+ ' routines ***')
- 9998 FORMAT( 1X, ' Error in RFP,convertion routines N=',I5,
+ 9998 FORMAT( 1X, ' Error in RFP,conversion routines N=',I5,
+ ' UPLO=''', A1, ''', FORM =''',A1,'''')
- 9997 FORMAT( 1X, 'All tests for the RFP convertion routines passed ( ',
+ 9997 FORMAT( 1X, 'All tests for the RFP conversion routines passed ( ',
+ I5,' tests run)')
- 9996 FORMAT( 1X, 'RFP convertion routines: ',I5,' out of ',I5,
+ 9996 FORMAT( 1X, 'RFP conversion routines: ',I5,' out of ',I5,
+ ' error message recorded')
*
RETURN
@@ -24,7 +24,7 @@
*> \verbatim
*>
-*> SDRVRF2 tests the LAPACK RFP convertion routines.
+*> SDRVRF2 tests the LAPACK RFP conversion routines.
*> \endverbatim
*
diff --git a/TESTING/LIN/zdrvrf2.f b/TESTING/LIN/zdrvrf2.f
index 0d4de1b3..7279c203 100644
--- a/TESTING/LIN/zdrvrf2.f
+++ b/TESTING/LIN/zdrvrf2.f
@@ -24,7 +24,7 @@
*>
*> \verbatim
*>
*> ZDRVRF2 tests the LAPACK RFP convertion routines.
*> \endverbatim
*
* Arguments:
@@ -248,13 +248,13 @@
WRITE( NOUT, FMT = 9996 ) NERRS, NRUN
END IF
*
- 9999 FORMAT( 1X, ' *** Error(s) while testing the RFP convertion',
+ 9999 FORMAT( 1X, ' *** Error(s) while testing the RFP conversion',
+ ' routines ***')
- 9998 FORMAT( 1X, ' Error in RFP,convertion routines N=',I5,
+ 9998 FORMAT( 1X, ' Error in RFP,conversion routines N=',I5,
+ ' UPLO=''', A1, ''', FORM =''',A1,'''')
- 9997 FORMAT( 1X, 'All tests for the RFP convertion routines passed (',
+ 9997 FORMAT( 1X, 'All tests for the RFP conversion routines passed (',
+ I5,' tests run)')
- 9996 FORMAT( 1X, 'RFP convertion routines:',I5,' out of ',I5,
+ 9996 FORMAT( 1X, 'RFP conversion routines:',I5,' out of ',I5,
+ ' error message recorded')
*
RETURN
@@ -24,7 +24,7 @@
*> \verbatim
*>
-*> ZDRVRF2 tests the LAPACK RFP convertion routines.
+*> ZDRVRF2 tests the LAPACK RFP conversion routines.
*> \endverbatim
*